@@ -1,8 +1,23 @@
 from collections import OrderedDict
 
-from typedpy.fields import StructureReference, Integer, Number, Float, Array, Enum, String, \
-    ClassReference, Field, Boolean, \
-    AllOf, OneOf, AnyOf, NotField, Tuple, Set
+from typedpy.fields import (
+    StructureReference,
+    Integer,
+    Number,
+    Float,
+    Array,
+    Enum,
+    String,
+    ClassReference,
+    Field,
+    Boolean,
+    AllOf,
+    OneOf,
+    AnyOf,
+    NotField,
+    Tuple,
+    Set,
+)
 
 from typedpy.extfields import DateString
 
@@ -27,20 +42,21 @@ def get_mapper(field_cls):
         OneOf: OneOfMapper,
         NotField: NotFieldMapper,
         Tuple: ArrayMapper,
-        Set: ArrayMapper
+        Set: ArrayMapper,
     }
     for cls in field_cls.__mro__:
         if issubclass(cls, Field) and cls in field_type_to_mapper:
             return field_type_to_mapper[cls]
-    raise NotImplementedError("schema mapping is not implemented for {}".
-                              format(field_cls))
+    raise NotImplementedError(
+        "schema mapping is not implemented for {}".format(field_cls)
+    )
 
 
 def _map_class_reference(reference, definitions_schema):
-    definition, _ = structure_to_schema(getattr(reference, '_ty'), definitions_schema)
-    name = getattr(reference, '_ty').__name__
+    definition, _ = structure_to_schema(getattr(reference, "_ty"), definitions_schema)
+    name = getattr(reference, "_ty").__name__
     definitions_schema[name] = definition
-    return {'$ref': '#/definitions/{}'.format(name)}
+    return {"$ref": "#/definitions/{}".format(name)}
 
 
 def convert_to_schema(field, definitions_schema):
@@ -79,18 +95,26 @@ def structure_to_schema(structure, definitions_schema):
     # json schema draft4 does not support inheritance, so we don't need to worry about that
     props = structure.__dict__
     fields = [key for key, val in props.items() if isinstance(val, Field)]
-    required = props.get('_required', fields)
-    additional_props = props.get('_additionalProperties', True)
+    required = props.get("_required", fields)
+    additional_props = props.get("_additionalProperties", True)
     if len(fields) == 1 and required == fields and additional_props is False:
-        return (convert_to_schema(props[fields[0]], definitions_schema), definitions_schema)
+        return (
+            convert_to_schema(props[fields[0]], definitions_schema),
+            definitions_schema,
+        )
     else:
-        fields_schema = OrderedDict([('type', 'object')])
-        fields_schema['properties'] = OrderedDict([(key, convert_to_schema(props[key], definitions_schema))
-                                                   for key in fields])
-        fields_schema.update(OrderedDict([
-            ('required', required),
-            ('additionalProperties', additional_props),
-        ]))
+        fields_schema = OrderedDict([("type", "object")])
+        fields_schema["properties"] = OrderedDict(
+            [(key, convert_to_schema(props[key], definitions_schema)) for key in fields]
+        )
+        fields_schema.update(
+            OrderedDict(
+                [
+                    ("required", required),
+                    ("additionalProperties", additional_props),
+                ]
+            )
+        )
     return (fields_schema, definitions_schema)
 
 
@@ -104,42 +128,39 @@ def convert_to_field_code(schema, definitions):
         return None
     if isinstance(schema, list):
         fields = [convert_to_field_code(s, definitions) for s in schema]
-        return '[{}]'.format(', '.join(fields))
-    if '$ref' in schema:
-        def_name = schema['$ref'][len('#/definitions/'):]
+        return "[{}]".format(", ".join(fields))
+    if "$ref" in schema:
+        def_name = schema["$ref"][len("#/definitions/") :]
         return def_name
 
     type_name_to_field = {
-        'object': StructureReference,
-        'integer': Integer,
-        'number': Number,
-        'float': Float,
-        'array': Array,
-        'string': String,
-        'boolean': Boolean
-    }
-    multivals = {
-        'allOf': AllOf,
-        'anyOf': AnyOf,
-        'oneOf': OneOf,
-        'not': NotField
+        "object": StructureReference,
+        "integer": Integer,
+        "number": Number,
+        "float": Float,
+        "array": Array,
+        "string": String,
+        "boolean": Boolean,
     }
+    multivals = {"allOf": AllOf, "anyOf": AnyOf, "oneOf": OneOf, "not": NotField}
     if any(multival in schema for multival in multivals):
         for (k, the_class) in multivals.items():
             if k in schema:
                 cls = the_class
         mapper = MultiFieldMapper
 
-    elif 'enum' in schema:
+    elif "enum" in schema:
         cls = Enum
         mapper = get_mapper(cls)
     else:
-        cls = type_name_to_field[schema.get('type', 'object')]
+        cls = type_name_to_field[schema.get("type", "object")]
         mapper = get_mapper(cls)
     params_list = mapper.get_paramlist_from_schema(schema, definitions)
 
-    params_as_string = ", ".join(["{}={}".format(name, val) for (name, val) in params_list])
-    return '{}({})'.format(cls.__name__, params_as_string)
+    params_as_string = ", ".join(
+        ["{}={}".format(name, val) for (name, val) in params_list]
+    )
+    return "{}({})".format(cls.__name__, params_as_string)
 
 
 def schema_to_struct_code(struct_name, schema, definitions_schema):
@@ -165,24 +186,41 @@ def schema_to_struct_code(struct_name, schema, definitions_schema):
         Note: In case schema is None, should return None.
         Deals with a schema that is a dict, as well as one that is a list
     """
-    body = ['class {}(Structure):'.format(struct_name)]
-    body += ['    """\n    {}\n    """\n'.format(schema.get('description'))] if 'description' \
-                                                                                in schema else []
-    body += ['    _additionalProperties = False'] if not \
-        schema.get('additionalProperties', True) else []
-    required = schema.get('required', None) if schema.get('type', 'object') == 'object' \
-        else ['wrapped']
-    body += ['    _required = {}'.format(required)] if required is not None else []
-    the_type = schema.get('type', 'object' if 'properties' in schema else None)
+    body = ["class {}(Structure):".format(struct_name)]
+    body += (
+        ['    """\n    {}\n    """\n'.format(schema.get("description"))]
+        if "description" in schema
+        else []
+    )
+    body += (
+        ["    _additionalProperties = False"]
+        if not schema.get("additionalProperties", True)
+        else []
+    )
+    required = (
+        schema.get("required", None)
+        if schema.get("type", "object") == "object"
+        else ["wrapped"]
+    )
+    body += ["    _required = {}".format(required)] if required is not None else []
+    the_type = schema.get("type", "object" if "properties" in schema else None)
 
-    if the_type == 'object':
-        properties = schema.get('properties', {})
+    if the_type == "object":
+        properties = schema.get("properties", {})
         for (name, sch) in properties.items():
-            body += ['    {} = {}'.format(name, convert_to_field_code(sch, definitions_schema))]
+            body += [
+                "    {} = {}".format(
+                    name, convert_to_field_code(sch, definitions_schema)
+                )
+            ]
     else:
-        body += ['    {} = {}'.format('wrapped', convert_to_field_code(schema, definitions_schema))]
+        body += [
+            "    {} = {}".format(
+                "wrapped", convert_to_field_code(schema, definitions_schema)
+            )
+        ]
 
-    return '\n'.join(body)
+    return "\n".join(body)
 
 
 def schema_definitions_to_code(schema):
@@ -200,7 +238,7 @@ def schema_definitions_to_code(schema):
     code = []
     for (name, sch) in schema.items():
         code.append(schema_to_struct_code(name, sch, schema))
-    return '\n\n'.join(code)
+    return "\n\n".join(code)
 
 
 def write_code_from_schema(schema, definitions_schema, filename, class_name):
@@ -228,7 +266,7 @@ def write_code_from_schema(schema, definitions_schema, filename, class_name):
     """
     supporting_classes = schema_definitions_to_code(definitions_schema)
     structure_code = schema_to_struct_code(class_name, schema, definitions_schema)
-    with open(filename, 'w') as fout:
+    with open(filename, "w") as fout:
         fout.write("from typedpy import *\n\n")
         fout.write(supporting_classes)
         fout.write("\n\n# ********************\n\n")
@@ -245,18 +283,23 @@ class StructureReferenceMapper(Mapper):
     @staticmethod
     def get_paramlist_from_schema(schema, definitions):
         body = []
-        body += [('_additionalProperties', False)] if not \
-            schema.get('additionalProperties', True) else []
-        required = schema.get('required', None)
-        body += [('_required', required)] if required is not None else []
-        properties = schema.get('properties', {})
+        body += (
+            [("_additionalProperties", False)]
+            if not schema.get("additionalProperties", True)
+            else []
+        )
+        required = schema.get("required", None)
+        body += [("_required", required)] if required is not None else []
+        properties = schema.get("properties", {})
 
-        body += [(k, convert_to_field_code(v, definitions)) for (k, v) in properties.items()]
+        body += [
+            (k, convert_to_field_code(v, definitions)) for (k, v) in properties.items()
+        ]
         return body
 
     def to_schema(self, definitions):
-        schema, _ = structure_to_schema(getattr(self.value, '_newclass'), definitions)
-        schema['type'] = 'object'
+        schema, _ = structure_to_schema(getattr(self.value, "_newclass"), definitions)
+        schema["type"] = "object"
         return schema
 
 
@@ -264,21 +307,21 @@ class NumberMapper(Mapper):
     @staticmethod
     def get_paramlist_from_schema(schema, definitions):
         params = {
-            'multiplesOf': schema.get('multiplesOf', None),
-            'minimum': schema.get('minimum', None),
-            'maximum': schema.get('maximum', None),
-            'exclusiveMaximum': schema.get('exclusiveMaximum', None)
+            "multiplesOf": schema.get("multiplesOf", None),
+            "minimum": schema.get("minimum", None),
+            "maximum": schema.get("maximum", None),
+            "exclusiveMaximum": schema.get("exclusiveMaximum", None),
         }
         return list((k, v) for k, v in params.items() if v is not None)
 
     def to_schema(self, definitions):
         value = self.value
         params = {
-            'type': 'number',
-            'multiplesOf': value.multiplesOf,
-            'minimum': value.minimum,
-            'maximum': value.maximum,
-            'exclusiveMaximum': value.exclusiveMaximum
+            "type": "number",
+            "multiplesOf": value.multiplesOf,
+            "minimum": value.minimum,
+            "maximum": value.maximum,
+            "exclusiveMaximum": value.exclusiveMaximum,
         }
         return dict([(k, v) for k, v in params.items() if v is not None])
 
@@ -286,14 +329,14 @@ class NumberMapper(Mapper):
 class IntegerMapper(NumberMapper):
     def to_schema(self, definitions):
         params = super().to_schema(definitions)
-        params.update({'type': 'integer'})
+        params.update({"type": "integer"})
         return params
 
 
 class FloatMapper(NumberMapper):
     def to_schema(self, definitions):
         params = super().to_schema(definitions)
-        params.update({'type': 'float'})
+        params.update({"type": "float"})
         return params
 
 
@@ -304,7 +347,7 @@ class BooleanMapper(Mapper):
 
     def to_schema(self, definitions):  # pylint: disable=R0201
         params = {
-            'type': 'boolean',
+            "type": "boolean",
         }
         return params
 
@@ -313,19 +356,19 @@ class StringMapper(Mapper):
     @staticmethod
     def get_paramlist_from_schema(schema, definitions):
         params = {
-            'minLength': schema.get('minLength', None),
-            'maxLength': schema.get('maxLength', None),
-            'pattern': as_str(schema.get('pattern', None)),
+            "minLength": schema.get("minLength", None),
+            "maxLength": schema.get("maxLength", None),
+            "pattern": as_str(schema.get("pattern", None)),
         }
         return list((k, v) for k, v in params.items() if v is not None)
 
     def to_schema(self, definitions):
         value = self.value
         params = {
-            'type': 'string',
-            'minLength': value.minLength,
-            'maxLength': value.maxLength,
-            'pattern': value.pattern
+            "type": "string",
+            "minLength": value.minLength,
+            "maxLength": value.maxLength,
+            "pattern": value.pattern,
         }
         return dict([(k, v) for k, v in params.items() if v is not None])
 
@@ -333,8 +376,8 @@ class StringMapper(Mapper):
 class DateStringMapper(Mapper):
     def to_schema(self, definitions):
         params = {
-            'type': 'string',
-            'pattern': r"^([12]\d{3}-(0[1-9]|1[0-2])-(0[1-9]|[12]\d|3[01]))$"
+            "type": "string",
+            "pattern": r"^([12]\d{3}-(0[1-9]|1[0-2])-(0[1-9]|[12]\d|3[01]))$",
         }
         return dict([(k, v) for k, v in params.items() if v is not None])
 
@@ -342,11 +385,11 @@ class DateStringMapper(Mapper):
 class ArrayMapper(Mapper):
     @staticmethod
     def get_paramlist_from_schema(schema, definitions):
-        items = schema.get('items', None)
+        items = schema.get("items", None)
         params = {
-            'uniqueItems': schema.get('uniqueItems', None),
-            'additionalItems': schema.get('additionalItems', None),
-            'items': convert_to_field_code(items, definitions)
+            "uniqueItems": schema.get("uniqueItems", None),
+            "additionalItems": schema.get("additionalItems", None),
+            "items": convert_to_field_code(items, definitions),
         }
         return list((k, v) for k, v in params.items() if v is not None)
 
@@ -354,27 +397,27 @@ class ArrayMapper(Mapper):
         value = self.value
         if isinstance(value, Tuple):
             params = {
-                'type': 'array',
-                'uniqueItems': value.uniqueItems,
-                'additionalItems': False,
-                'items': convert_to_schema(value.items, definitions)
+                "type": "array",
+                "uniqueItems": value.uniqueItems,
+                "additionalItems": False,
+                "items": convert_to_schema(value.items, definitions),
             }
         elif isinstance(value, Set):
             params = {
-                'type': 'array',
-                'uniqueItems': True,
-                'maxItems': value.maxItems,
-                'minItems': value.minItems,
-                'items': convert_to_schema(value.items, definitions)
+                "type": "array",
+                "uniqueItems": True,
+                "maxItems": value.maxItems,
+                "minItems": value.minItems,
+                "items": convert_to_schema(value.items, definitions),
             }
         else:
             params = {
-                'type': 'array',
-                'uniqueItems': value.uniqueItems,
-                'additionalItems': value.additionalItems,
-                'maxItems': value.maxItems,
-                'minItems': value.minItems,
-                'items': convert_to_schema(value.items, definitions)
+                "type": "array",
+                "uniqueItems": value.uniqueItems,
+                "additionalItems": value.additionalItems,
+                "maxItems": value.maxItems,
+                "minItems": value.minItems,
+                "items": convert_to_schema(value.items, definitions),
             }
         return dict([(k, v) for k, v in params.items() if v is not None])
 
@@ -383,14 +426,12 @@ class EnumMapper(Mapper):
     @staticmethod
     def get_paramlist_from_schema(schema, definitions):
         params = {
-            'values': schema.get('enum', None),
+            "values": schema.get("enum", None),
         }
         return list(params.items())
 
     def to_schema(self, definitions):
-        params = {
-            'enum': self.value.values
-        }
+        params = {"enum": self.value.values}
         return dict([(k, v) for k, v in params.items() if v is not None])
 
 
@@ -398,27 +439,25 @@ class MultiFieldMapper(object):
     @staticmethod
     def get_paramlist_from_schema(schema, definitions):
         items = list(schema.values())[0]
-        params = {
-            'fields': convert_to_field_code(items, definitions)
-        }
+        params = {"fields": convert_to_field_code(items, definitions)}
         return list(params.items())
 
 
 class AllOfMapper(Mapper):
     def to_schema(self, definitions):
-        return {'allOf': convert_to_schema(self.value._fields, definitions)}
+        return {"allOf": convert_to_schema(self.value._fields, definitions)}
 
 
 class OneOfMapper(Mapper):
     def to_schema(self, definitions):
-        return {'oneOf': convert_to_schema(self.value._fields, definitions)}
+        return {"oneOf": convert_to_schema(self.value._fields, definitions)}
 
 
 class AnyOfMapper(Mapper):
     def to_schema(self, definitions):
-        return {'anyOf': convert_to_schema(self.value._fields, definitions)}
+        return {"anyOf": convert_to_schema(self.value._fields, definitions)}
 
 
 class NotFieldMapper(Mapper):
     def to_schema(self, definitions):
-        return {'not': convert_to_schema(self.value._fields, definitions)}
+        return {"not": convert_to_schema(self.value._fields, definitions)}
